<?php /*

**************************************************************************

Plugin Name:  Dashboard: Pending Review
Plugin URI:   http://www.viper007bond.com/wordpress-plugins/dashboard-pending-review/
Description:  Displays pending review posts on your dashboard.
Version:      2.0.0
Author:       Viper007Bond
Author URI:   http://www.viper007bond.com/

**************************************************************************/

class DashboardPendingReview {

	// Class initialization
	function DashboardPendingReview() {
		if ( !current_user_can( 'edit_posts' ) )
			return;

		// Load up the localization file if we're using WordPress in a different language
		// Place it in this plugin's folder and name it "dashboard-pending-review-[value in wp-config].mo"
		load_plugin_textdomain( 'dashboard-pending-review', false, '/wp-content/plugins/dashboard-pending-review/localization' );

		// Hooks!
		add_action( 'admin_head', array(&$this, 'css') );
		add_action( 'wp_dashboard_setup', array(&$this, 'register_widget') );
		add_filter( 'wp_dashboard_widgets', array(&$this, 'add_widget') );
	}


	// Register this widget -- we use a hook/function to make the widget a dashboard-only widget
	function register_widget() {
		wp_register_sidebar_widget( 'dashboard_pending_review', __( 'Posts Pending Review', 'dashboard-pending-review' ), array(&$this, 'widget') );
	}


	// Some content styling for the widget
	function css() { ?>
<style type="text/css">
	#dashboard_pending_review ul {
		margin: 0;
		padding: 0;
		list-style: none;
	}
	#dashboard_pending_review ul li {
		margin-bottom: 0.6em;
	}
	#dashboard_pending_review h4 {
		font-weight: normal;
	}
	#dashboard_pending_review h4 abbr {
		font-family: "Lucida Grande", Verdana, Arial, "Bitstream Vera Sans", sans-serif;
		font-size: 11px;
		color: #999;
		margin-left: 3px;
	}
	#dashboard_pending_review p {
		margin: 0;
		padding: 0;
	}
</style>
<?php
	}


	// Modifies the array of dashboard widgets and adds this plugin's
	function add_widget( $widgets ) {
		global $wp_registered_widgets;

		if ( !isset($wp_registered_widgets['dashboard_pending_review']) )
			return $widgets;

		$widgets[] = 'dashboard_pending_review';

		return $widgets;
	}


	// Output the widget contents
	function widget( $args ) {
		$pendings_query = new WP_Query( array(
			'post_type' => 'post',
			'what_to_show' => 'posts',
			'post_status' => 'pending',
			'posts_per_page' => 25,
			'orderby' => 'ID', // sort by order created, regardless of date
			'order' => 'DESC'
		) );
		$pendings =& $pendings_query->posts;

		if ( $pendings && is_array( $pendings ) ) {
			$list = array();
			foreach ( $pendings as $pending ) {
				$url = get_edit_post_link( $pending->ID );
				$title = _draft_or_post_title( $pending->ID );
				$item = "<h4><a href='$url' title='" . sprintf( __( 'Edit "%s"' ), attribute_escape( $title ) ) . "'>$title</a>";
				//if ( $pending->au
				$item .= "<abbr title='" . get_the_time(__('Y/m/d g:i:s A'), $pending) . "'>" . get_the_time( get_option( 'date_format' ), $pending ) . '</abbr></h4>';
				if ( $the_content = preg_split( '#\s#', strip_tags( $pending->post_content ), 11, PREG_SPLIT_NO_EMPTY ) )
					$item .= '<p>' . join( ' ', array_slice( $the_content, 0, 10 ) ) . ( 10 < count( $the_content ) ? '&hellip;' : '' ) . '</p>';
				$list[] = $item;
			}
?>
	<ul>
		<li><?php echo join( "</li>\n<li>", $list ); ?></li>
	</ul>
	<p class="textright"><a href="edit.php?post_status=pending" class="button"><?php _e('View all'); ?></a></p>
<?php
		} else {
			_e( 'There are no pending posts at the moment', 'dashboard-scheduled-posts' );
		}
	}
}

// Start this plugin once all other plugins are fully loaded
add_action( 'plugins_loaded', create_function( '', 'global $DashboardPendingReview; $DashboardPendingReview = new DashboardPendingReview();' ) );

?>